@@ -7,21 +7,28 @@ from actstream import feeds
 
 
 urlpatterns = patterns('actstream.views',
-    # Syndication Feeds
-    url(r'^feed/(?P<content_type_id>\d+)/(?P<object_id>\d+)/atom/$',
-        feeds.AtomObjectActivityFeed(), name='actstream_object_feed_atom'),
-    url(r'^feed/(?P<content_type_id>\d+)/(?P<object_id>\d+)/$',
-        feeds.ObjectActivityFeed(), name='actstream_object_feed'),
-    url(r'^feed/(?P<content_type_id>\d+)/atom/$',
-        feeds.AtomModelActivityFeed(), name='actstream_model_feed_atom'),
-    url(r'^feed/(?P<content_type_id>\d+)/(?P<object_id>\d+)/as/$',
-        feeds.ActivityStreamsObjectActivityFeed(),
-        name='actstream_object_feed_as'),
-    url(r'^feed/(?P<content_type_id>\d+)/$',
-        feeds.ModelActivityFeed(), name='actstream_model_feed'),
+    # User feeds
     url(r'^feed/$', feeds.UserActivityFeed(), name='actstream_feed'),
     url(r'^feed/atom/$', feeds.AtomUserActivityFeed(),
         name='actstream_feed_atom'),
+    url(r'^feed/json/$', feeds.UserJSONActivityFeed.as_view(),
+        name='actstream_feed_json'),
+
+    # Object feeds
+    url(r'^feed/(?P<content_type_id>\d+)/(?P<object_id>\d+)/$',
+        feeds.ObjectActivityFeed(), name='actstream_object_feed'),
+    url(r'^feed/(?P<content_type_id>\d+)/(?P<object_id>\d+)/atom/$',
+        feeds.AtomObjectActivityFeed(), name='actstream_object_feed_atom'),
+    url(r'^feed/(?P<content_type_id>\d+)/(?P<object_id>\d+)/json/$',
+        feeds.ObjectJSONActivityFeed.as_view(), name='actstream_object_feed_json'),
+
+    # Model feeds
+    url(r'^feed/(?P<content_type_id>\d+)/$',
+        feeds.ModelActivityFeed(), name='actstream_model_feed'),
+    url(r'^feed/(?P<content_type_id>\d+)/atom/$',
+        feeds.AtomModelActivityFeed(), name='actstream_model_feed_atom'),
+    url(r'^feed/(?P<content_type_id>\d+)/json/$',
+        feeds.ModelJSONActivityFeed.as_view(), name='actstream_model_feed_json'),
 
     # Follow/Unfollow API
     url(r'^follow/(?P<content_type_id>\d+)/(?P<object_id>\d+)/$',
@@ -34,6 +41,8 @@ urlpatterns = patterns('actstream.views',
     # Follower and Actor lists
     url(r'^followers/(?P<content_type_id>\d+)/(?P<object_id>\d+)/$',
         'followers', name='actstream_followers'),
+    url(r'^following/(?P<user_id>\d+)/$',
+        'following', name='actstream_following'),
     url(r'^actors/(?P<content_type_id>\d+)/(?P<object_id>\d+)/$',
         'actor', name='actstream_actor'),
     url(r'^actors/(?P<content_type_id>\d+)/$',
